@@ -106,7 +106,8 @@ class ImageDownloaderWorker(Thread):
                         img.save(local_image_path, 'JPEG', quality=quality, optimize=True)
                 except IOError as e:
                     print(("No valid image found %s" % (local_image_path,)))
-                    os.remove(local_image_path)
+                    if os.path.exists(local_image_path):
+                        os.remove(local_image_path)
                 except KeyboardInterrupt:
                     self.controller['running'] = False
 
@@ -217,7 +218,7 @@ def read_images_in_memory(job_model, dataset, node, trainer):
     images = []
     max = 0
 
-    path = trainer.job_model.get_dataset_downloads_dir(dataset)
+    path = job_model.get_dataset_downloads_dir(dataset)
     if 'path' in dataset['config']:
         path = dataset['config']['path']
 
@@ -225,6 +226,8 @@ def read_images_in_memory(job_model, dataset, node, trainer):
     category_map = {}
     classes = []
 
+    trainer.set_status('LOAD IMAGES INTO MEMORY')
+
     try:
         for i in range(concurrent):
             t = ImageReadWorker(q, job_model, node, path, images, controller)
@@ -279,6 +282,7 @@ def read_images_in_memory(job_model, dataset, node, trainer):
                                      'config']['settings']['batchSize'])
 
         nb_sample = len(train_images)
+        trainer.set_info('Dataset size', {'training': nb_sample, 'validation': len(test_images)})
         trainer.set_generator_training_nb(nb_sample)
         trainer.set_generator_validation_nb(len(test_images))
 
@@ -290,7 +294,7 @@ def read_images_in_memory(job_model, dataset, node, trainer):
             sys.exit(1)
 
         trainer.output_size = classes_count
-        trainer.set_job_system_info('classes', classes)
+        trainer.set_info('Classes', classes)
         trainer.classes = classes
 
         result['X_train'] = train
@@ -368,8 +372,6 @@ def read_images_keras_generator(job_model, dataset, node, trainer):
     trainer.set_job_system_info('classes', classes)
     trainer.classes = classes
 
-    trainer.output_size = train_generator.nb_class
-
     # ensure_dir(dataset_config['path'] + '/preview')
 
     test_datagen = ImageDataGenerator(rescale=1. / 255)
@@ -377,15 +379,35 @@ def read_images_keras_generator(job_model, dataset, node, trainer):
         directory=os.path.join(dataset_config['path'], 'validation'),
         # save_to_dir=dataset_config['path'] + '/preview',
         target_size=size,
-        batch_size=trainer.get_batch_size(),
+        batch_size=job_model.get_batch_size(),
         color_mode='grayscale' if grayscale is True else 'rgb',
         class_mode='categorical')
 
-    trainer.set_generator_validation_nb(validation_generator.nb_sample)
-    trainer.set_generator_training_nb(train_generator.nb_sample)
+    validation_samples = 0
+    train_samples = 0
+
+    # Keras 2
+    if hasattr(train_generator, 'num_class'):
+        trainer.output_size = train_generator.num_class
+    if hasattr(train_generator, 'samples'):
+        train_samples = train_generator.samples
+    if hasattr(validation_generator, 'samples'):
+        validation_samples = validation_generator.samples
+
+    # Keras 1
+    if hasattr(train_generator, 'nb_class'):
+        trainer.output_size = train_generator.nb_class
+    if hasattr(train_generator, 'nb_sample'):
+        train_samples = train_generator.nb_sample
+    if hasattr(validation_generator, 'nb_sample'):
+        validation_samples = validation_generator.nb_sample
+
+    trainer.set_info('Dataset size', {'training': train_samples, 'validation': len(validation_samples)})
+    trainer.set_generator_validation_nb(validation_samples)
+    trainer.set_generator_training_nb(train_samples)
 
     print(("Found %d classes, %d images (%d in training [%saugmented], %d in validation) in %s " %
-           (len(classes), validation_generator.nb_sample + train_generator.nb_sample, train_generator.nb_sample, 'not ' if augmentation is False else '', validation_generator.nb_sample, dataset_config['path'])))
+           (len(classes), validation_samples + train_samples, train_samples, 'not ' if augmentation is False else '', validation_samples, dataset_config['path'])))
 
     if trainer.output_size == 0:
         print("Could not find any classes. Does the directory contains images?")
@@ -405,10 +427,15 @@ def read_images_keras_generator(job_model, dataset, node, trainer):
 def get_images(job_model, dataset, node, trainer):
     concurrent = 15
 
+    from PIL import ImageFile
+    if hasattr(ImageFile, 'LOAD_TRUNCATED_IMAGES'):
+        ImageFile.LOAD_TRUNCATED_IMAGES = True
+
+
     q = Queue(concurrent)
     config = dataset['config']
 
-    dir = trainer.job_model.get_dataset_downloads_dir(dataset)
+    dir = job_model.get_dataset_downloads_dir(dataset)
 
     ensure_dir(dir)
 
@@ -423,24 +450,27 @@ def get_images(job_model, dataset, node, trainer):
 
     classes = config['classes']
 
-    trainer.set_status('PREPARE_IMAGES')
+    trainer.set_status('LOAD IMAGES')
 
     max = 0
     images = {}
 
-    dataset_path = trainer.job_model.get_dataset_downloads_dir(dataset)
+    dataset_path = job_model.get_dataset_downloads_dir(dataset)
     meta_information_file = dataset_path + '/meta.json'
 
     classes_changed = False
     config_changed = False
     had_previous = False
-    classes_md5 = hashlib.md5(json.dumps(classes, default=invalid_json_values).encode('utf-8')).hexdigest()
+    classes_md5 = hashlib.md5(json.dumps(classes, default=invalid_json_values, sort_keys=True).encode('utf-8')).hexdigest()
 
     validationFactor = 0.2
 
+    meta = {}
     if os.path.isdir(dataset_path):
         if os.path.isfile(meta_information_file):
+            print("meta.json exists!")
             with open(meta_information_file) as f:
+                print("meta.json content", f)
                 meta = json.load(f)
                 if meta:
                     had_previous = True
@@ -459,12 +489,13 @@ def get_images(job_model, dataset, node, trainer):
     need_download = classes_changed or config_changed
 
     if need_download:
+
         if had_previous:
             print("Reset dataset and re-download images to " + dir)
             if classes_changed:
-                print(" .. because classes changed")
+                print(" .. because classes changed in", meta['classes_md5'], classes_md5, meta_information_file)
             if config_changed:
-                print(" .. because settings changed")
+                print(" .. because settings changed in", meta_information_file)
         else:
             print("Download images to " + dir)
 
@@ -474,7 +505,7 @@ def get_images(job_model, dataset, node, trainer):
                           int(get_option(config, 'resizeHeight', 64)))
             print(" .. with resizing to %dx%d " % resizeSize)
 
-        # we need to donwload all images
+        # # we need to donwload all images
         shutil.rmtree(dataset_path)
 
         controller = {'running': True}
@@ -523,6 +554,7 @@ def get_images(job_model, dataset, node, trainer):
                     'classes_md5': classes_md5,
                     'config': config
                 }
+                print("save meta.json", classes_md5)
                 json.dump(meta, f, default=invalid_json_values)
 
         except KeyboardInterrupt:
@@ -533,7 +565,6 @@ def get_images(job_model, dataset, node, trainer):
         print(" - Remove this directory if you want to re-download all images of your dataset and re-shuffle training/validation images.")
 
     trainer.output_size = len(classes)
-    trainer.set_status('LOAD IMAGE DONE')
 
     # change to type local_images
     dataset_transformed = dataset.copy()
