@@ -12,7 +12,6 @@ class StartCommand:
         parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, prog=aetros.const.__prog__ + ' start')
         parser.add_argument('name', nargs='?', help='the model name, e.g. aetros/mnist-network, or job id, e.g. 1WPXxQP0j.')
         parser.add_argument('--insights', action='store_true', help="activates insights. Only for Keras models.")
-        parser.add_argument('--insights-sample', help="Path or url to the sample being used to generate the insights. Default is first model sample. Only for Keras models.")
         parser.add_argument('--dataset', help="Dataset id when model has placeholders. Only for Keras models with placeholders as input/output.")
         parser.add_argument('--api-key', help="Secure key. Alternatively use API_KEY environment varibale.")
         parser.add_argument('--gpu', action='store_true', help="Activates GPU if available. Only for Theano models.")
@@ -61,6 +60,5 @@ class StartCommand:
             hyperparameter=hyperparameter,
             dataset_id=parsed_args.dataset,
             insights=parsed_args.insights,
-            insights_sample_path=parsed_args.insights_sample,
             api_key=parsed_args.api_key,
         )
